@@ -2,7 +2,10 @@ from typing import Dict
 
 import networkx as nx
 import numpy as np
-import tensorflow as tf
+try:
+    import tensorflow as tf
+except ImportError:
+    tf = None
 
 from nfp.preprocessing.preprocessor import PreprocessorMultiGraph
 from nfp.preprocessing.tokenizer import Tokenizer
@@ -15,7 +18,6 @@ class PymatgenPreprocessor(PreprocessorMultiGraph):
         self.radius = radius
         self.num_neighbors = num_neighbors
 
-
     def create_nx_graph(self, crystal, **kwargs) -> nx.MultiDiGraph:
         """ crystal should be a pymatgen.core.Structure object.
         """
@@ -79,6 +81,8 @@ class PymatgenPreprocessor(PreprocessorMultiGraph):
 
     @property
     def output_signature(self) -> Dict[str, tf.TensorSpec]:
+        if tf is None:
+            raise ImportError('Tensorflow was not found')
         return {
             'site': tf.TensorSpec(shape=(None,), dtype=self.output_dtype),
             'distance': tf.TensorSpec(shape=(None,), dtype='float32'),
@@ -88,6 +92,8 @@ class PymatgenPreprocessor(PreprocessorMultiGraph):
 
     @property
     def padding_values(self) -> Dict[str, tf.constant]:
+        if tf is None:
+            raise ImportError('Tensorflow was not found')
         return {
             'site': tf.constant(0, dtype=self.output_dtype),
             'distance': tf.constant(np.nan, dtype='float32'),
@@ -96,6 +102,8 @@ class PymatgenPreprocessor(PreprocessorMultiGraph):
 
     @property
     def tfrecord_features(self) -> Dict[str, tf.io.FixedLenFeature]:
+        if tf is None:
+            raise ImportError('Tensorflow was not found')
         return {
             key: tf.io.FixedLenFeature([], dtype=tf.string)
             for key in self.output_signature.keys()
