@@ -1,15 +1,15 @@
 class Tokenizer(object):
-    """ A class to turn arbitrary inputs into integer classes. """
+    """A class to turn arbitrary inputs into integer classes."""
 
     def __init__(self):
         # the default class for an unseen entry during test-time
-        self._data = {'unk': 1}
-        self._num_classes = 1
+        self._data = {"unk": 1}
+        self.num_classes = 1
         self.train = True
         self.unknown = []
 
     def __call__(self, item):
-        """ Check to see if the Tokenizer has seen `item` before, and if so,
+        """Check to see if the Tokenizer has seen `item` before, and if so,
         return the integer class associated with it. Otherwise, if we're
         training, create a new integer class, otherwise return the 'unknown'
         class.
@@ -26,13 +26,8 @@ class Tokenizer(object):
             else:
                 # Record the unknown item, then return the unknown label
                 self.unknown += [item]
-                return self._data['unk']
-
-    @property
-    def num_classes(self) -> int:
-        """The maximum number of assigned classes"""
-        return self._num_classes
+                return self._data["unk"]
 
     def _add_token(self, item):
-        self._num_classes += 1
-        self._data[item] = self._num_classes
+        self.num_classes += 1
+        self._data[item] = self.num_classes
